@@ -25,8 +25,7 @@ from contextlib import suppress
 from winrm.exceptions import WinRMOperationTimeoutError
 from winrm.protocol import Protocol
 
-from airflow.exceptions import AirflowException
-from airflow.providers.common.compat.sdk import BaseHook
+from airflow.providers.common.compat.sdk import AirflowException, BaseHook
 from airflow.utils.platform import getuser
 
 # TODO: FIXME please - I have too complex implementation
